#[shared]Expand description
An attribute to place a static variable in shared memory
This static variable will refer to the same memory location on all cores
#[shared]An attribute to place a static variable in shared memory
This static variable will refer to the same memory location on all cores